document.addEventListener('DOMContentLoaded', function () {
  const editor = document.getElementById('editor');
  const fileList = document.getElementById('fileList');

  // Basic formatting event listeners
  document.getElementById('boldBtn').addEventListener('click', () => {
    document.execCommand('bold');
  });

  document.getElementById('italicBtn').addEventListener('click', () => {
    document.execCommand('italic');
  });

  document.getElementById('underlineBtn').addEventListener('click', () => {
    document.execCommand('underline');
  });

  // Font Family
  document.getElementById('fontFamilySelect').addEventListener('change', (event) => {
    document.execCommand('fontName', false, event.target.value);
  });

  // Font Size (execCommand expects values 1-7)
  document.getElementById('fontSizeSelect').addEventListener('change', (event) => {
    document.execCommand('fontSize', false, event.target.value);
  });

  // Text Color
  document.getElementById('textColorInput').addEventListener('change', (event) => {
    document.execCommand('foreColor', false, event.target.value);
  });

  // Background Color
  document.getElementById('bgColorInput').addEventListener('change', (event) => {
    document.execCommand('backColor', false, event.target.value);
  });

  // Bullet List
  document.getElementById('bulletListBtn').addEventListener('click', () => {
    document.execCommand('insertUnorderedList', false, null);
  });

  // Numbered List
  document.getElementById('numberedListBtn').addEventListener('click', () => {
    document.execCommand('insertOrderedList', false, null);
  });

  // Block Quote
  document.getElementById('blockQuoteBtn').addEventListener('click', () => {
    document.execCommand('formatBlock', false, 'blockquote');
  });

  // Headings
  document.getElementById('headingSelect').addEventListener('change', (event) => {
    document.execCommand('formatBlock', false, event.target.value);
  });

  // New Alignment Buttons
  document.getElementById('alignLeftBtn').addEventListener('click', () => {
    document.execCommand('justifyLeft');
  });

  document.getElementById('alignCenterBtn').addEventListener('click', () => {
    document.execCommand('justifyCenter');
  });

  document.getElementById('alignRightBtn').addEventListener('click', () => {
    document.execCommand('justifyRight');
  });

  document.getElementById('alignJustifyBtn').addEventListener('click', () => {
    document.execCommand('justifyFull');
  });

  // New Link Buttons
  document.getElementById('insertLinkBtn').addEventListener('click', () => {
    const url = prompt("Enter the URL:");
    if (url) {
      document.execCommand('createLink', false, url);
    }
  });

  document.getElementById('removeLinkBtn').addEventListener('click', () => {
    document.execCommand('unlink');
  });

  // New Undo/Redo Buttons
  document.getElementById('undoBtn').addEventListener('click', () => {
    document.execCommand('undo');
  });

  document.getElementById('redoBtn').addEventListener('click', () => {
    document.execCommand('redo');
  });

  // New Export Button
  document.getElementById('exportBtn').addEventListener('click', () => {
    const content = editor.innerHTML;
    const blob = new Blob([content], { type: 'text/html' });
    const url = URL.createObjectURL(blob);
    chrome.downloads.download({
      url: url,
      filename: 'document.html',
      saveAs: true
    });
  });

  // Status Bar Update
  function updateStatusBar() {
    const text = editor.innerText || editor.textContent;
    const words = text.trim() === '' ? 0 : text.trim().split(/\s+/).length;
    const chars = text.length;
    document.getElementById('wordCount').textContent = `Words: ${words}`;
    document.getElementById('charCount').textContent = `Characters: ${chars}`;
  }

  editor.addEventListener('input', updateStatusBar);
  updateStatusBar();

  // Auto-Save Draft
  chrome.storage.local.get({ draft: '' }, function (result) {
    if (result.draft) {
      editor.innerHTML = result.draft;
      updateStatusBar();
    }
  });

  setInterval(() => {
    chrome.storage.local.set({ draft: editor.innerHTML });
  }, 5000);

  // New File and Save File Event Listeners
  document.getElementById('newFileBtn').addEventListener('click', () => {
    if (confirm("Start a new document? Unsaved changes will be lost.")) {
      editor.innerHTML = "";
      chrome.storage.local.remove('draft');
      updateStatusBar();
    }
  });

  document.getElementById('saveFileBtn').addEventListener('click', saveFile);

  // Save file to chrome.storage.local
  function saveFile() {
    const fileName = prompt("Enter a name for your file:");
    if (!fileName) return;

    const content = editor.innerHTML;
    chrome.storage.local.get({ files: {} }, function (result) {
      let files = result.files;
      files[fileName] = content;
      chrome.storage.local.set({ files: files }, function () {
        alert("File saved successfully!");
        loadFileDirectory();
      });
    });
  }

  // Delete file function
  function deleteFile(fileName) {
    if (!confirm(`Are you sure you want to delete "${fileName}"?`)) {
      return;
    }

    chrome.storage.local.get({ files: {} }, function (result) {
      let files = result.files;
      delete files[fileName];
      chrome.storage.local.set({ files: files }, function () {
        alert(`File "${fileName}" deleted.`);
        loadFileDirectory();
      });
    });
  }

  // Rename file function
  function renameFile(oldName) {
    const newName = prompt("Enter new name for the file:", oldName);
    if (!newName || newName === oldName) return;

    chrome.storage.local.get({ files: {} }, function (result) {
      let files = result.files;
      if (files[newName]) {
        alert("A file with that name already exists.");
        return;
      }
      if (!files[oldName]) {
        alert("File not found.");
        return;
      }
      files[newName] = files[oldName];
      delete files[oldName];
      chrome.storage.local.set({ files: files }, function () {
        alert(`File renamed to "${newName}".`);
        loadFileDirectory();
      });
    });
  }

  // Load file directory with rename and sort
  function loadFileDirectory() {
    chrome.storage.local.get({ files: {} }, function (result) {
      let files = result.files;
      let fileNames = Object.keys(files).sort();
      fileList.innerHTML = "";
      fileNames.forEach(fileName => {
        let li = document.createElement("li");
        li.textContent = fileName;

        // Create delete button ("x")
        let deleteBtn = document.createElement("span");
        deleteBtn.textContent = "x";
        deleteBtn.className = "delete-button";
        deleteBtn.addEventListener("click", (event) => {
          event.stopPropagation();
          deleteFile(fileName);
        });

        // Create rename button ("✎")
        let renameBtn = document.createElement("span");
        renameBtn.textContent = "✎";
        renameBtn.className = "rename-button";
        renameBtn.addEventListener("click", (event) => {
          event.stopPropagation();
          renameFile(fileName);
        });

        li.appendChild(deleteBtn);
        li.appendChild(renameBtn);

        // Clicking the file name loads the file
        li.addEventListener("click", () => {
          if (confirm(`Load file "${fileName}"? Unsaved changes will be lost.`)) {
            editor.innerHTML = files[fileName];
            updateStatusBar();
          }
        });

        fileList.appendChild(li);
      });
    });
  }

  // File Search Functionality
  document.getElementById('fileSearch').addEventListener('input', (event) => {
    const searchTerm = event.target.value.toLowerCase();
    const lis = fileList.getElementsByTagName('li');
    Array.from(lis).forEach(li => {
      const fileName = li.textContent.toLowerCase();
      if (fileName.includes(searchTerm)) {
        li.style.display = '';
      } else {
        li.style.display = 'none';
      }
    });
  });

  // Initial load of file directory
  loadFileDirectory();
});